@@ -7,6 +7,6 @@ if __name__ == '__main__':
     import os
     pkg_dir = os.path.dirname(os.path.abspath(__file__))
     main = os.path.join(pkg_dir, '__main__.py')
-    execfile(main)
+    exec(open(main).read())
 
 
